import * as React from "react";
import { PropertyControls, ControlType } from "framer";
import styled, { css } from "styled-components";

const Bvtton = styled.div`
    height: 100%;
    display: flex;
    flex-direction: row;
    align-items: center;
    justify-content: center;
    padding: 8px 16px;

    /* Button label */
    span {
        font-family: 'Inknut Antiqua', Georgia, 'Times New Roman', Times, serif; /* Check the fonts folder for more info */
        font-size: 16px;
        font-weight: 400;
        font-style: normal;
        line-height: 1;
        letter-spacing: 2px;
        text-transform: uppercase;
        text-align: center;
        text-rendering: optimizeLegibility;
        position: relative;
        transition: all 250ms cubic-bezier(0.19, 1, 0.22, 1) 250ms;
    }

    /* Button container */
    &:after {
        content: '';
        width: 100%;
        height: 100%;
        position: absolute;
        left: 0;
        z-index: -1;
        transform-origin: center;
        transition: all 200ms cubic-bezier(0.95, 0.05, 0.795, 0.035);
    }

    /* Strikethrough that appears on hover */
    &:before {
        content: '';
        width: 0;
        height: 2px;
        background: #EE4444;
        border: solid 2px #EE4444;
        opacity: 0;
        position: absolute;
        left: 0;
        transform-origin: center left;
        transition: all 250ms cubic-bezier(0.19, 1, 0.22, 1) 250ms;
    }

    /* Hover states */
    &:hover {
        span {
            color: #EE4444;
        }
        &:after {
            height: 0;
        }
        &:before {
            width: 100%;
            opacity: 1;
        }
    }

    /* Outline styling */
    ${props => props.styling == 'outline' && css`
        span {
            color: #555;
        }
        
        &:after {
            background: transparent;
            border: solid 2px #555;
        }
    `}

    /* Fill styling */
    ${props => props.styling == 'fill' && css`
        span {
            color: #111;
        }

        &:after {
            background: #555;
            border: solid 2px #555;
        }
    `}
`

// Define type of property
interface Props {
    text: string;
    styling: string;
    // Default button size when rendered on the canvas
    width: number;
    height: number;
}

export class bvtton extends React.Component<Props> {

    // Set default properties
    static defaultProps = {
        text: "Bvtton",
        styling: "outline",
        width: 185,
        height: 56,
    }

    // Items shown in property panel
    static propertyControls: PropertyControls = {
        text: {
            type: ControlType.String,
            title: "Label"
        },
        styling: {
            type: ControlType.SegmentedEnum, 
            title: "Style",
            options: ["outline", "fill"],
            optionTitles: ["Outline", "Fill"]
        },

    }

    render() {
        return <Bvtton styling={this.props.styling}><span>{this.props.text}</span></Bvtton>;
    }
}